HistoSeg
========

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/pattern1_isoline

.. toctree::
   :maxdepth: 1
   :caption: Architecture

   ai_driven_spatial_pathologist_architecture
